@@ -16,28 +16,30 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.accessapproval_v1.services.access_approval import pagers
-from google.cloud.accessapproval_v1.types import accessapproval
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import AccessApprovalTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import AccessApprovalGrpcAsyncIOTransport
+
+from google.cloud.accessapproval_v1.services.access_approval import pagers
+from google.cloud.accessapproval_v1.types import accessapproval
+
 from .client import AccessApprovalClient
+from .transports.base import DEFAULT_CLIENT_INFO, AccessApprovalTransport
+from .transports.grpc_asyncio import AccessApprovalGrpcAsyncIOTransport
 
 
 class AccessApprovalAsyncClient:
@@ -83,6 +85,12 @@ class AccessApprovalAsyncClient:
     DEFAULT_ENDPOINT = AccessApprovalClient.DEFAULT_ENDPOINT
     DEFAULT_MTLS_ENDPOINT = AccessApprovalClient.DEFAULT_MTLS_ENDPOINT
 
+    access_approval_service_account_path = staticmethod(
+        AccessApprovalClient.access_approval_service_account_path
+    )
+    parse_access_approval_service_account_path = staticmethod(
+        AccessApprovalClient.parse_access_approval_service_account_path
+    )
     access_approval_settings_path = staticmethod(
         AccessApprovalClient.access_approval_settings_path
     )
@@ -261,14 +269,13 @@ class AccessApprovalAsyncClient:
         filtered by state (pending, active, dismissed). The
         order is reverse chronological.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
 
-            def sample_list_approval_requests():
+            async def sample_list_approval_requests():
                 # Create a client
-                client = accessapproval_v1.AccessApprovalClient()
+                client = accessapproval_v1.AccessApprovalAsyncClient()
 
                 # Initialize request argument(s)
                 request = accessapproval_v1.ListApprovalRequestsMessage(
@@ -278,7 +285,7 @@ class AccessApprovalAsyncClient:
                 page_result = client.list_approval_requests(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -349,12 +356,20 @@ class AccessApprovalAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListApprovalRequestsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -372,21 +387,20 @@ class AccessApprovalAsyncClient:
         r"""Gets an approval request. Returns NOT_FOUND if the request does
         not exist.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
 
-            def sample_get_approval_request():
+            async def sample_get_approval_request():
                 # Create a client
-                client = accessapproval_v1.AccessApprovalClient()
+                client = accessapproval_v1.AccessApprovalAsyncClient()
 
                 # Initialize request argument(s)
                 request = accessapproval_v1.GetApprovalRequestMessage(
                 )
 
                 # Make the request
-                response = client.get_approval_request(request=request)
+                response = await client.get_approval_request(request=request)
 
                 # Handle the response
                 print(response)
@@ -454,7 +468,12 @@ class AccessApprovalAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -473,21 +492,20 @@ class AccessApprovalAsyncClient:
         FAILED_PRECONDITION if the request exists but is not in a
         pending state.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
 
-            def sample_approve_approval_request():
+            async def sample_approve_approval_request():
                 # Create a client
-                client = accessapproval_v1.AccessApprovalClient()
+                client = accessapproval_v1.AccessApprovalAsyncClient()
 
                 # Initialize request argument(s)
                 request = accessapproval_v1.ApproveApprovalRequestMessage(
                 )
 
                 # Make the request
-                response = client.approve_approval_request(request=request)
+                response = await client.approve_approval_request(request=request)
 
                 # Handle the response
                 print(response)
@@ -526,7 +544,12 @@ class AccessApprovalAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -550,21 +573,20 @@ class AccessApprovalAsyncClient:
         Returns FAILED_PRECONDITION if the request exists but is not in
         a pending state.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
 
-            def sample_dismiss_approval_request():
+            async def sample_dismiss_approval_request():
                 # Create a client
-                client = accessapproval_v1.AccessApprovalClient()
+                client = accessapproval_v1.AccessApprovalAsyncClient()
 
                 # Initialize request argument(s)
                 request = accessapproval_v1.DismissApprovalRequestMessage(
                 )
 
                 # Make the request
-                response = client.dismiss_approval_request(request=request)
+                response = await client.dismiss_approval_request(request=request)
 
                 # Handle the response
                 print(response)
@@ -603,7 +625,92 @@ class AccessApprovalAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def invalidate_approval_request(
+        self,
+        request: Union[accessapproval.InvalidateApprovalRequestMessage, dict] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> accessapproval.ApprovalRequest:
+        r"""Invalidates an existing ApprovalRequest. Returns the updated
+        ApprovalRequest.
+
+        NOTE: This does not deny access to the resource if another
+        request has been made and approved. It only invalidates a single
+        approval.
+
+        Returns FAILED_PRECONDITION if the request exists but is not in
+        an approved state.
+
+        .. code-block:: python
+
+            from google.cloud import accessapproval_v1
+
+            async def sample_invalidate_approval_request():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalAsyncClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.InvalidateApprovalRequestMessage(
+                )
+
+                # Make the request
+                response = await client.invalidate_approval_request(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.accessapproval_v1.types.InvalidateApprovalRequestMessage, dict]):
+                The request object. Request to invalidate an existing
+                approval.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.accessapproval_v1.types.ApprovalRequest:
+                A request for the customer to approve
+                access to a resource.
+
+        """
+        # Create or coerce a protobuf request object.
+        request = accessapproval.InvalidateApprovalRequestMessage(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.invalidate_approval_request,
+            default_timeout=600.0,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -620,21 +727,20 @@ class AccessApprovalAsyncClient:
         r"""Gets the settings associated with a project, folder,
         or organization.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
 
-            def sample_get_access_approval_settings():
+            async def sample_get_access_approval_settings():
                 # Create a client
-                client = accessapproval_v1.AccessApprovalClient()
+                client = accessapproval_v1.AccessApprovalAsyncClient()
 
                 # Initialize request argument(s)
                 request = accessapproval_v1.GetAccessApprovalSettingsMessage(
                 )
 
                 # Make the request
-                response = client.get_access_approval_settings(request=request)
+                response = await client.get_access_approval_settings(request=request)
 
                 # Handle the response
                 print(response)
@@ -705,7 +811,12 @@ class AccessApprovalAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -724,21 +835,20 @@ class AccessApprovalAsyncClient:
         organization. Settings to update are determined by the value of
         field_mask.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
 
-            def sample_update_access_approval_settings():
+            async def sample_update_access_approval_settings():
                 # Create a client
-                client = accessapproval_v1.AccessApprovalClient()
+                client = accessapproval_v1.AccessApprovalAsyncClient()
 
                 # Initialize request argument(s)
                 request = accessapproval_v1.UpdateAccessApprovalSettingsMessage(
                 )
 
                 # Make the request
-                response = client.update_access_approval_settings(request=request)
+                response = await client.update_access_approval_settings(request=request)
 
                 # Handle the response
                 print(response)
@@ -817,7 +927,12 @@ class AccessApprovalAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -840,21 +955,20 @@ class AccessApprovalAsyncClient:
         still be enabled at this level as the settings are
         inherited.
 
-
         .. code-block:: python
 
             from google.cloud import accessapproval_v1
 
-            def sample_delete_access_approval_settings():
+            async def sample_delete_access_approval_settings():
                 # Create a client
-                client = accessapproval_v1.AccessApprovalClient()
+                client = accessapproval_v1.AccessApprovalAsyncClient()
 
                 # Initialize request argument(s)
                 request = accessapproval_v1.DeleteAccessApprovalSettingsMessage(
                 )
 
                 # Make the request
-                client.delete_access_approval_settings(request=request)
+                await client.delete_access_approval_settings(request=request)
 
         Args:
             request (Union[google.cloud.accessapproval_v1.types.DeleteAccessApprovalSettingsMessage, dict]):
@@ -906,9 +1020,112 @@ class AccessApprovalAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
+    async def get_access_approval_service_account(
+        self,
+        request: Union[
+            accessapproval.GetAccessApprovalServiceAccountMessage, dict
+        ] = None,
+        *,
+        name: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> accessapproval.AccessApprovalServiceAccount:
+        r"""Retrieves the service account that is used by Access
+        Approval to access KMS keys for signing approved
+        approval requests.
+
+        .. code-block:: python
+
+            from google.cloud import accessapproval_v1
+
+            async def sample_get_access_approval_service_account():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalAsyncClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.GetAccessApprovalServiceAccountMessage(
+                )
+
+                # Make the request
+                response = await client.get_access_approval_service_account(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.accessapproval_v1.types.GetAccessApprovalServiceAccountMessage, dict]):
+                The request object. Request to get an Access Approval
+                service account.
+            name (:class:`str`):
+                Name of the
+                AccessApprovalServiceAccount to
+                retrieve.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.accessapproval_v1.types.AccessApprovalServiceAccount:
+                Access Approval service account
+                related to a
+                project/folder/organization.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = accessapproval.GetAccessApprovalServiceAccountMessage(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if name is not None:
+            request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.get_access_approval_service_account,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     async def __aenter__(self):
         return self
 
