@@ -13,20 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
 
 from google.cloud.accessapproval_v1.types import accessapproval
-from google.protobuf import empty_pb2  # type: ignore
-from .base import AccessApprovalTransport, DEFAULT_CLIENT_INFO
+
+from .base import DEFAULT_CLIENT_INFO, AccessApprovalTransport
 
 
 class AccessApprovalGrpcTransport(AccessApprovalTransport):
@@ -259,8 +258,7 @@ class AccessApprovalGrpcTransport(AccessApprovalTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -393,6 +391,43 @@ class AccessApprovalGrpcTransport(AccessApprovalTransport):
             )
         return self._stubs["dismiss_approval_request"]
 
+    @property
+    def invalidate_approval_request(
+        self,
+    ) -> Callable[
+        [accessapproval.InvalidateApprovalRequestMessage],
+        accessapproval.ApprovalRequest,
+    ]:
+        r"""Return a callable for the invalidate approval request method over gRPC.
+
+        Invalidates an existing ApprovalRequest. Returns the updated
+        ApprovalRequest.
+
+        NOTE: This does not deny access to the resource if another
+        request has been made and approved. It only invalidates a single
+        approval.
+
+        Returns FAILED_PRECONDITION if the request exists but is not in
+        an approved state.
+
+        Returns:
+            Callable[[~.InvalidateApprovalRequestMessage],
+                    ~.ApprovalRequest]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "invalidate_approval_request" not in self._stubs:
+            self._stubs["invalidate_approval_request"] = self.grpc_channel.unary_unary(
+                "/google.cloud.accessapproval.v1.AccessApproval/InvalidateApprovalRequest",
+                request_serializer=accessapproval.InvalidateApprovalRequestMessage.serialize,
+                response_deserializer=accessapproval.ApprovalRequest.deserialize,
+            )
+        return self._stubs["invalidate_approval_request"]
+
     @property
     def get_access_approval_settings(
         self,
@@ -495,8 +530,46 @@ class AccessApprovalGrpcTransport(AccessApprovalTransport):
             )
         return self._stubs["delete_access_approval_settings"]
 
+    @property
+    def get_access_approval_service_account(
+        self,
+    ) -> Callable[
+        [accessapproval.GetAccessApprovalServiceAccountMessage],
+        accessapproval.AccessApprovalServiceAccount,
+    ]:
+        r"""Return a callable for the get access approval service
+        account method over gRPC.
+
+        Retrieves the service account that is used by Access
+        Approval to access KMS keys for signing approved
+        approval requests.
+
+        Returns:
+            Callable[[~.GetAccessApprovalServiceAccountMessage],
+                    ~.AccessApprovalServiceAccount]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_access_approval_service_account" not in self._stubs:
+            self._stubs[
+                "get_access_approval_service_account"
+            ] = self.grpc_channel.unary_unary(
+                "/google.cloud.accessapproval.v1.AccessApproval/GetAccessApprovalServiceAccount",
+                request_serializer=accessapproval.GetAccessApprovalServiceAccountMessage.serialize,
+                response_deserializer=accessapproval.AccessApprovalServiceAccount.deserialize,
+            )
+        return self._stubs["get_access_approval_service_account"]
+
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("AccessApprovalGrpcTransport",)
