@@ -13,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.accessapproval.v1",
@@ -25,20 +23,24 @@ __protobuf__ = proto.module(
         "EnrollmentLevel",
         "AccessLocations",
         "AccessReason",
+        "SignatureInfo",
         "ApproveDecision",
         "DismissDecision",
         "ResourceProperties",
         "ApprovalRequest",
         "EnrolledService",
         "AccessApprovalSettings",
+        "AccessApprovalServiceAccount",
         "ListApprovalRequestsMessage",
         "ListApprovalRequestsResponse",
         "GetApprovalRequestMessage",
         "ApproveApprovalRequestMessage",
         "DismissApprovalRequestMessage",
+        "InvalidateApprovalRequestMessage",
         "GetAccessApprovalSettingsMessage",
         "UpdateAccessApprovalSettingsMessage",
         "DeleteAccessApprovalSettingsMessage",
+        "GetAccessApprovalServiceAccountMessage",
     },
 )
 
@@ -87,8 +89,14 @@ class AccessLocations(proto.Message):
             -  ANY: Any location
     """
 
-    principal_office_country = proto.Field(proto.STRING, number=1,)
-    principal_physical_location_country = proto.Field(proto.STRING, number=2,)
+    principal_office_country = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    principal_physical_location_country = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class AccessReason(proto.Message):
@@ -108,9 +116,61 @@ class AccessReason(proto.Message):
         CUSTOMER_INITIATED_SUPPORT = 1
         GOOGLE_INITIATED_SERVICE = 2
         GOOGLE_INITIATED_REVIEW = 3
+        THIRD_PARTY_DATA_REQUEST = 4
+        GOOGLE_RESPONSE_TO_PRODUCTION_ALERT = 5
 
-    type_ = proto.Field(proto.ENUM, number=1, enum=Type,)
-    detail = proto.Field(proto.STRING, number=2,)
+    type_ = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=Type,
+    )
+    detail = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+
+
+class SignatureInfo(proto.Message):
+    r"""Information about the digital signature of the resource.
+
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
+    Attributes:
+        signature (bytes):
+            The digital signature.
+        google_public_key_pem (str):
+            The public key for the Google default
+            signing, encoded in PEM format. The signature
+            was created using a private key which may be
+            verified using this public key.
+
+            This field is a member of `oneof`_ ``verification_info``.
+        customer_kms_key_version (str):
+            The resource name of the customer
+            CryptoKeyVersion used for signing.
+
+            This field is a member of `oneof`_ ``verification_info``.
+    """
+
+    signature = proto.Field(
+        proto.BYTES,
+        number=1,
+    )
+    google_public_key_pem = proto.Field(
+        proto.STRING,
+        number=2,
+        oneof="verification_info",
+    )
+    customer_kms_key_version = proto.Field(
+        proto.STRING,
+        number=3,
+        oneof="verification_info",
+    )
 
 
 class ApproveDecision(proto.Message):
@@ -122,12 +182,40 @@ class ApproveDecision(proto.Message):
             The time at which approval was granted.
         expire_time (google.protobuf.timestamp_pb2.Timestamp):
             The time at which the approval expires.
+        invalidate_time (google.protobuf.timestamp_pb2.Timestamp):
+            If set, denotes the timestamp at which the
+            approval is invalidated.
+        signature_info (google.cloud.accessapproval_v1.types.SignatureInfo):
+            The signature for the ApprovalRequest and
+            details on how it was signed.
+        auto_approved (bool):
+            True when the request has been auto-approved.
     """
 
     approve_time = proto.Field(
-        proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    expire_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    invalidate_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    signature_info = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="SignatureInfo",
+    )
+    auto_approved = proto.Field(
+        proto.BOOL,
+        number=5,
     )
-    expire_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
 
 
 class DismissDecision(proto.Message):
@@ -139,16 +227,21 @@ class DismissDecision(proto.Message):
             dismissed.
         implicit (bool):
             This field will be true if the
-            ApprovalRequest was implcitly dismissed due to
+            ApprovalRequest was implicitly dismissed due to
             inaction by the access approval approvers (the
             request is not acted on by the approvers before
             the exiration time).
     """
 
     dismiss_time = proto.Field(
-        proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    implicit = proto.Field(
+        proto.BOOL,
+        number=2,
     )
-    implicit = proto.Field(proto.BOOL, number=2,)
 
 
 class ResourceProperties(proto.Message):
@@ -160,7 +253,10 @@ class ResourceProperties(proto.Message):
             descendants of the resource being requested.
     """
 
-    excludes_descendants = proto.Field(proto.BOOL, number=1,)
+    excludes_descendants = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
 
 
 class ApprovalRequest(proto.Message):
@@ -212,26 +308,50 @@ class ApprovalRequest(proto.Message):
             This field is a member of `oneof`_ ``decision``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    requested_resource_name = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    requested_resource_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     requested_resource_properties = proto.Field(
-        proto.MESSAGE, number=9, message="ResourceProperties",
+        proto.MESSAGE,
+        number=9,
+        message="ResourceProperties",
+    )
+    requested_reason = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="AccessReason",
     )
-    requested_reason = proto.Field(proto.MESSAGE, number=3, message="AccessReason",)
     requested_locations = proto.Field(
-        proto.MESSAGE, number=4, message="AccessLocations",
+        proto.MESSAGE,
+        number=4,
+        message="AccessLocations",
     )
     request_time = proto.Field(
-        proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
     )
     requested_expiration = proto.Field(
-        proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
     )
     approve = proto.Field(
-        proto.MESSAGE, number=7, oneof="decision", message="ApproveDecision",
+        proto.MESSAGE,
+        number=7,
+        oneof="decision",
+        message="ApproveDecision",
     )
     dismiss = proto.Field(
-        proto.MESSAGE, number=8, oneof="decision", message="DismissDecision",
+        proto.MESSAGE,
+        number=8,
+        oneof="decision",
+        message="DismissDecision",
     )
 
 
@@ -303,8 +423,15 @@ class EnrolledService(proto.Message):
             The enrollment level of the service.
     """
 
-    cloud_product = proto.Field(proto.STRING, number=1,)
-    enrollment_level = proto.Field(proto.ENUM, number=2, enum="EnrollmentLevel",)
+    cloud_product = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    enrollment_level = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum="EnrollmentLevel",
+    )
 
 
 class AccessApprovalSettings(proto.Message):
@@ -348,14 +475,86 @@ class AccessApprovalSettings(proto.Message):
             or Folder (this field will always be unset for
             the organization since organizations do not have
             ancestors).
+        active_key_version (str):
+            The asymmetric crypto key version to use for signing
+            approval requests. Empty active_key_version indicates that a
+            Google-managed key should be used for signing. This property
+            will be ignored if set by an ancestor of this resource, and
+            new non-empty values may not be set.
+        ancestor_has_active_key_version (bool):
+            Output only. This field is read only (not settable via
+            UpdateAccessApprovalSettings method). If the field is true,
+            that indicates that an ancestor of this Project or Folder
+            has set active_key_version (this field will always be unset
+            for the organization since organizations do not have
+            ancestors).
+        invalid_key_version (bool):
+            Output only. This field is read only (not settable via
+            UpdateAccessApprovalSettings method). If the field is true,
+            that indicates that there is some configuration issue with
+            the active_key_version configured at this level in the
+            resource hierarchy (e.g. it doesn't exist or the Access
+            Approval service account doesn't have the correct
+            permissions on it, etc.) This key version is not necessarily
+            the effective key version at this level, as key versions are
+            inherited top-down.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    notification_emails = proto.RepeatedField(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    notification_emails = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
     enrolled_services = proto.RepeatedField(
-        proto.MESSAGE, number=3, message="EnrolledService",
+        proto.MESSAGE,
+        number=3,
+        message="EnrolledService",
+    )
+    enrolled_ancestor = proto.Field(
+        proto.BOOL,
+        number=4,
+    )
+    active_key_version = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    ancestor_has_active_key_version = proto.Field(
+        proto.BOOL,
+        number=7,
+    )
+    invalid_key_version = proto.Field(
+        proto.BOOL,
+        number=8,
+    )
+
+
+class AccessApprovalServiceAccount(proto.Message):
+    r"""Access Approval service account related to a
+    project/folder/organization.
+
+    Attributes:
+        name (str):
+            The resource name of the Access Approval service account.
+            Format is one of:
+
+            -  "projects/{project}/serviceAccount"
+            -  "folders/{folder}/serviceAccount"
+            -  "organizations/{organization}/serviceAccount".
+        account_email (str):
+            Email address of the service account.
+    """
+
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    account_email = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    enrolled_ancestor = proto.Field(proto.BOOL, number=4,)
 
 
 class ListApprovalRequestsMessage(proto.Message):
@@ -387,10 +586,22 @@ class ListApprovalRequestsMessage(proto.Message):
             return.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListApprovalRequestsResponse(proto.Message):
@@ -409,9 +620,14 @@ class ListApprovalRequestsResponse(proto.Message):
         return self
 
     approval_requests = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="ApprovalRequest",
+        proto.MESSAGE,
+        number=1,
+        message="ApprovalRequest",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetApprovalRequestMessage(proto.Message):
@@ -423,7 +639,10 @@ class GetApprovalRequestMessage(proto.Message):
             "{projects|folders|organizations}/{id}/approvalRequests/{approval_request}".
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ApproveApprovalRequestMessage(proto.Message):
@@ -436,8 +655,15 @@ class ApproveApprovalRequestMessage(proto.Message):
             The expiration time of this approval.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    expire_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    expire_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class DismissApprovalRequestMessage(proto.Message):
@@ -448,7 +674,24 @@ class DismissApprovalRequestMessage(proto.Message):
             Name of the ApprovalRequest to dismiss.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+
+
+class InvalidateApprovalRequestMessage(proto.Message):
+    r"""Request to invalidate an existing approval.
+
+    Attributes:
+        name (str):
+            Name of the ApprovalRequest to invalidate.
+    """
+
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class GetAccessApprovalSettingsMessage(proto.Message):
@@ -460,7 +703,10 @@ class GetAccessApprovalSettingsMessage(proto.Message):
             "{projects|folders|organizations}/{id}/accessApprovalSettings".
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateAccessApprovalSettingsMessage(proto.Message):
@@ -483,9 +729,15 @@ class UpdateAccessApprovalSettingsMessage(proto.Message):
             field will be updated.
     """
 
-    settings = proto.Field(proto.MESSAGE, number=1, message="AccessApprovalSettings",)
+    settings = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="AccessApprovalSettings",
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -497,7 +749,25 @@ class DeleteAccessApprovalSettingsMessage(proto.Message):
             Name of the AccessApprovalSettings to delete.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+
+
+class GetAccessApprovalServiceAccountMessage(proto.Message):
+    r"""Request to get an Access Approval service account.
+
+    Attributes:
+        name (str):
+            Name of the AccessApprovalServiceAccount to
+            retrieve.
+    """
+
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
